# Table of Contents

- [modeling-and-reports](<./modeling-and-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling and Reports](<./Modeling-and-Reports.md>)
  - [Scenario: Reflecting GDPR Status of Applications in Reports](<./Modeling-and-Reports/Scenario-Reflecting-GDPR-Status-of-Applications-in-Reports.md>)
